GetSuburbFromName
^^^^^^^^^^^^^^^^^

`GetSuburbFromName?Suburb=ALBERT%20PARK <https://www.waterconnect.sa.gov.au/_layouts/15/dfw.sharepoint.wdd/WDDWFS.ashx/GetSuburbFromName?Suburb=ALBERT%20PARK>`__

.. include:: polyline-explainer.rst

Returns (this only shows 2 of many returned "DHNO" records):

.. code-block:: json

    [
      {
        "OBJECTID": 54,
        "POSTCODE": "5014",
        "SUBURB": "ALBERT PARK",
        "SHAPE.AREA": 909903.92320695,
        "SHAPE.LEN": 4694.4468670681,
        "URL": "http:\/\/sdsi.sa.gov.au\/arcgis\/rest\/services\/DEWNRint\/WaterConnect_WaterConnect\/MapServer\/",
        "DHNO": [
          {
            "DHNO": 55783,
            "LAT": -34.8780246,
            "LON": 138.5248554,
            "MAPNUM": 662808814,
            "UNIT_NO": "6628-8814",
            "MAX_DEPTH": 36.58,
            "SWL": 6.1,
            "TDS": 1113,
            "CLASS": "WW",
            "TITLE_PREFIX": "CT",
            "TITLE_VOLUME": "5481",
            "TITLE_FOLIO": "437",
            "HUND": "YATALA",
            "PARCEL": "A",
            "PARCELNO": "50",
            "PLAN": "F",
            "PLANNO": "14451",
            "PWA": "Central Adelaide",
            "NRM": "Adelaide & Mt Lofty Ranges",
            "LOGDRILL": "N",
            "LITHOLOG": "N",
            "CHEM": "Y",
            "WATER": "Y",
            "SAL": "Y",
            "OBSWELL": "N",
            "STRATLOG": "N",
            "HSTRATLOG": "N",
            "LATEST_SWL_DATE": "1946-01-09",
            "LATEST_SAL_DATE": "1946-01-09",
            "LATEST_OPEN_DEPTH": 36.58,
            "LATEST_OPEN_DATE": "1946-01-09"
          },
          {
            "DHNO": 284994,
            "LAT": -34.8732987,
            "LON": 138.5238972,
            "MAPNUM": 662827724,
            "UNIT_NO": "6628-27724",
            "MAX_DEPTH": 5,
            "PERMIT_NO": 243932,
            "PURP_DESC": "INV",
            "SWL": 4.8,
            "CLASS": "WW",
            "HUND": "YATALA",
            "PWA": "Central Adelaide",
            "NRM": "Adelaide & Mt Lofty Ranges",
            "LOGDRILL": "N",
            "LITHOLOG": "N",
            "CHEM": "N",
            "WATER": "Y",
            "SAL": "N",
            "OBSWELL": "N",
            "STRATLOG": "N",
            "HSTRATLOG": "N",
            "LATEST_SWL_DATE": "2015-04-15",
            "LATEST_OPEN_DEPTH": 5,
            "LATEST_OPEN_DATE": "2015-04-15"
          }
        ],
        "Boundary": [
          "pvzsE{golYnCwE\\nAj@xAp@dBFN~AzCFH?@b@p@fAzAzAlBVZFHrBlBhEzDlD|C|ArAfA`ArI|HFFA?U\\CD_BrCkAnBy@B}HLsFN??k@FaHROByGPwBFOAPfL_BD_ELcBFeABaABmBDY@mBFe@@A[uQh@sELA?dFwIj@_AHQjAmBzDyGx@uApDiGpBkD|@{AbCcExAgCz@yAjIqN"
        ]
      }
    ]
